package com.ruoyi.nanjing.mapper;

import java.util.List;
import com.ruoyi.nanjing.domain.TBdStationtype;

/**
 * 工位类型Mapper接口
 * 
 * @author limy
 * @date 2021-01-22
 */
public interface TBdStationtypeMapper 
{
    /**
     * 查询工位类型
     * 
     * @param ID 工位类型ID
     * @return 工位类型
     */
    public TBdStationtype selectTBdStationtypeById(Long ID);

    /**
     * 查询工位类型列表
     * 
     * @param tBdStationtype 工位类型
     * @return 工位类型集合
     */
    public List<TBdStationtype> selectTBdStationtypeList(TBdStationtype tBdStationtype);

    /**
     * 新增工位类型
     * 
     * @param tBdStationtype 工位类型
     * @return 结果
     */
    public int insertTBdStationtype(TBdStationtype tBdStationtype);

    /**
     * 修改工位类型
     * 
     * @param tBdStationtype 工位类型
     * @return 结果
     */
    public int updateTBdStationtype(TBdStationtype tBdStationtype);

    /**
     * 删除工位类型
     * 
     * @param ID 工位类型ID
     * @return 结果
     */
    public int deleteTBdStationtypeById(Long ID);

    /**
     * 批量删除工位类型
     * 
     * @param IDs 需要删除的数据ID
     * @return 结果
     */
    public int deleteTBdStationtypeByIds(String[] IDs);
}
